@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for iot1click-devices service client paginators.
 
@@ -18,23 +19,23 @@ Usage::
     list_devices_paginator: ListDevicesPaginator = client.get_paginator("list_devices")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_iot1click_devices.type_defs import (
     ListDeviceEventsResponseTypeDef,
     ListDevicesResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = ("ListDeviceEventsPaginator", "ListDevicesPaginator")
 
 
 class ListDeviceEventsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeviceEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
+    [Paginator.ListDeviceEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
     """
 
     def paginate(
@@ -45,18 +46,18 @@ class ListDeviceEventsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListDeviceEventsResponseTypeDef]:
         """
-        [ListDeviceEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents.paginate)
+        [ListDeviceEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents.paginate)
         """
 
 
 class ListDevicesPaginator(Boto3Paginator):
     """
-    [Paginator.ListDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
+    [Paginator.ListDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
     """
 
     def paginate(
         self, DeviceType: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDevicesResponseTypeDef]:
         """
-        [ListDevices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices.paginate)
+        [ListDevices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices.paginate)
         """
